/*
 *  Copyright  2005, Interlink Electronics Inc.  All Rights Reserved.
 *
 */

// **********************************************************************
//
// msgproc.h: Jefferson Message Processing header file
//
// This module contains data type and function definitions that constitute 
// public interface to the Jefferson Message Processing routines
//

#ifndef __MSGPROC_H
#define __MSGPROC_H

#include "main.h"
#include "pad.h"
#include "lcd_output_manager.h"
#include "usb_io.h"

typedef enum {
    PEN_OFF,    // No inking
    PEN_ON,     // Inking all the time
    PEN_ON_TO   // Inking with timeout
} INKING_MODES;    
    
// **********************************************************************
// *** Global functions for usb-comm and message-processing operations

extern thread_proc_rtn *msgproc_get_pad_data_pump_thread_entry_point();
extern BOOL msgproc_get_feature(STRINGPTR inpBuffer, BUFFERPTR outBuffer, INT16U *buffLen);
extern BOOL msgproc_set_feature(STRINGPTR inpBuffer, INT16U buffLen);

// **********************************************************************
// These functions are for returning the appropriate HID get-feature-report data
extern BOOL msgproc_hid_get_serial_number(PSERIALNUM_REPORT outbuffer);
extern BOOL msgproc_hid_get_cal_info(PSYSCAL_REPORT outbuffer);
extern BOOL msgproc_hid_get_eeprom_data(PREAD_EEPROM_REPORT outbuffer);
extern BOOL msgproc_hid_get_save_settings(PSAVE_SETTINGS_REPORT outbuffer);
extern BOOL msgproc_hid_get_diffie_hellman_shared_private_key(PDATA_ENCRYPT_REPORT outbuffer);
extern BOOL msgproc_hid_get_report_rate(PREPORT_RATE_REPORT outbuffer);
extern BOOL msgproc_hid_get_pad_info(PPAD_INFO_REPORT outbuffer);
extern BOOL msgproc_hid_get_lcd_info(PLCD_INFO_REPORT outbuffer);

// **********************************************************************
// These functions are for processing the appropriate HID set-feature-report data
extern BOOL msgproc_hid_set_inking_region(PSERIALNUM_REPORT outbuffer);

// **********************************************************************
// *** Accessor functions for individual operations ***

// This is called once and only once...
extern void msgproc_accessor_init();

// This function sets the values as defined in the message from the host
// If the values are in range then function returns TRUE, else it returns FALSE
extern BOOL msgproc_set_inking_region(INT16U xStart, INT16U yStart, INT16U xLen, INT16U yLen);

// This function returns the start and end coordinates (or region) of the inking region
// If the inking region is valid, then function returns TRUE, else it returns FALSE
extern BOOL msgproc_get_inking_coords(INT16U *xStart, INT16U *yStart, INT16U *xEnd, INT16U *yEnd);
extern BOOL msgproc_get_inking_region(INT16U *xStart, INT16U *yStart, INT16U *xLen, INT16U *yLen);

// This function sets the values as defined in the message from the host
// If the values are in range then function returns TRUE, else it returns FALSE
extern void msgproc_set_inking_color(BYTE red, BYTE green, BYTE blue);

// This function returns the color value (used for drawing) for inking color
// One should insure that inking region is valid before obtaining this value
// (see msgproc_get_inking_region)
extern o_color_t msgproc_get_inking_color();

// This function sets the values as defined in the message from the host
// If the values are in range then function returns TRUE, else it returns FALSE
extern BOOL msgproc_set_inking_pen_mode(BYTE mode, INT16U timeout);

// This function returns the pen mode (used for drawing) for "ink trails"
// One should insure that inking region is valid before obtaining this value
// (see msgproc_get_inking_region)
extern INKING_MODES msgproc_get_inking_pen_mode(INT32U *timeout);
#endif
